Advanced
========

.. toctree::
    :titlesonly:
    :maxdepth: 2

    API reference tool <APIReferenceTool>
    Test suite <Testsuite>
    Command line interface <CommandLineInterface>
    Data preprocessing and exporting <DataPreprocessing>
    Using non-English characters <Unicode>
    Using fonts <Fonts>
    Presenting videos <Video>
    Plugin system (extras) <Plugins>
    Defaults (settings) <Defaults>
    Hardware compatibility <Hardware>
    Timing <Timing>
    Problems & Limitations <Problems>
